<?php
/**
 * Linework functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Linework
 */

if ( ! function_exists( 'linework_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function linework_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Linework, use a find and replace
	 * to change 'linework' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'linework', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 960, 540, false );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'linework' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
		'script',
		'style',
		'navigation-widgets'
	) );

	/*
	 * Allow widgets to be previewed faster in the customizer with selective refresh.
	 */
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	add_theme_support( 'custom-logo', array(
		'height' => 115,
		'width' => 230,
		'flex-width' => true,
		'header-text' => array( 'site-title', 'site-description' ),
		'unlink-homepage-logo' => true,
	) );

	/*
	 * This theme styles the visual editor to resemble the theme style.
	 */
	// Bug in core or with google fonts where only one weight can be requested in a given url (commas are stripped).
	$editor_style_urls = array( 'editor-style.css', 'https://fonts.googleapis.com/css?family=Assistant:200', 'https://fonts.googleapis.com/css?family=Assistant:300', 'https://fonts.googleapis.com/css?family=Assistant:600' );
	add_editor_style( $editor_style_urls );

	/*
	 * Define and register starter content to showcase the theme on new sites.
 	 */
	$starter_content = array(
		'widgets' => array(
			'footer' => array( // Place three core-defined widgets in the sidebar area.
				'search',
				'text_business_info',
				'text_about',
			),
		),

		// Specify the core-defined pages to create and add custom thumbnails to some of them.
		'posts' => array(
			'home',
			'about',
			'contact',
			'blog',
		),

		// Default to a static front page and assign the front and posts pages.
		'options' => array(
			'show_on_front' => 'page',
			'page_on_front' => '{{home}}',
			'page_for_posts' => '{{blog}}',
		),

		// Set up a nav menu for the primary location.
		'nav_menus' => array(
			'primary' => array(
				'name' => __( 'Primary Menu', 'linework' ),
				'items' => array(
					'link_home', // Note that the core "home" page is actually a link in case a static front page is not used.
					'page_about',
					'page_blog',
					'page_contact',
				),
			),
		),
	);

	/**
	 * Filter Linework starter content array.
	 *
	 * @since Linework 1.0
	 *
	 * @param $starter_content array
	 */
	add_theme_support( 'starter-content', apply_filters( 'linework_starter_content', $starter_content ) );

	// Disable user-defined font size selection to encourage consistency.
	add_theme_support( 'disable-custom-font-sizes' );
	
	// Disable color pickers in the editor in favor of colors defined in the customizer.
	add_theme_support( 'disable-custom-colors' );
	
	// Load classic editor styles into the block editor.
	add_theme_support( 'editor-styles' );
	
	// Load default block styles.
	add_theme_support( 'wp-block-styles' );
	
	// Add support for wide alignments in the block editor;
	add_theme_support( 'align-wide' );
	
	// Add support for custom color scheme.
	add_theme_support(
		'editor-color-palette',
		array(
			array(
				'name'  => __( 'Linework', 'linework' ),
				'slug'  => 'linework',
				'color' => get_theme_mod( 'linework_color', '#20a' ),
			),
			array(
				'name'  => __( 'Contrast', 'linework' ),
				'slug'  => 'contrast',
				'color' => get_theme_mod( 'lw_background_color', '#fffcf7' ),
			),
			array(
				'name'  => __( 'White', 'linework' ),
				'slug'  => 'white',
				'color' => '#fff',
			),
			array(
				'name'  => __( 'Black', 'linework' ),
				'slug'  => 'black',
				'color' => '#000',
			),
		)
	);

	// Disable gradients.
	add_theme_support( 'disable-custom-gradients' );
	add_theme_support( 'editor-gradient-presets', array() );

}
endif;
add_action( 'after_setup_theme', 'linework_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function linework_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'linework_content_width', 960 );
}
add_action( 'after_setup_theme', 'linework_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function linework_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widgets', 'linework' ),
		'id'            => 'footer',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'linework_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function linework_scripts() {
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'linework-fonts', 'https://fonts.googleapis.com/css?family=Assistant:200,300,600', array(), null );

	wp_enqueue_style( 'linework-style', get_stylesheet_uri() );

	wp_enqueue_script( 'linework-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20200226', true );

	wp_enqueue_script( 'linework', get_template_directory_uri() . '/js/linework.js', array( 'jquery' ), '20160625', true );

	// Load theme options to pass to the Linework script.
	$animate = get_theme_mod( 'lw_animate', false );
	$initial = absint( get_theme_mod( 'lw_initial', 100 ) );
	$color = esc_html( sanitize_hex_color( get_theme_mod( 'linework_color', '#20a' ) ) );
	if ( 1 === $animate ) {
		$animate = true;
	} else {
		$animate = false;
	}

	// Pass data to JS.
	$settings = array(
		'animate'   => $animate,
		'initial' => $initial,
		'color'   => $color,
	);

	wp_localize_script( 'linework', 'lineworkSettings', $settings );

	// Misc. theme scripts.
	wp_enqueue_script( 'linework-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array( 'jquery' ), '20160704', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'linework_scripts' );

/**
 * Enqueue styles for the block-based editor.
 *
 * @since Figure/Ground 1.3
 */
function linework_block_editor_styles() {
	// Add custom fonts. These do not work with `add_editor_style` in the block editor.
	wp_enqueue_style( 'linework-fonts', 'https://fonts.googleapis.com/css?family=Assistant:200,300,600', array(), null );
}
add_action( 'enqueue_block_editor_assets', 'linework_block_editor_styles' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load custom styles for embeds.
 */
require get_template_directory() . '/inc/embed-styles.php';